Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/phpmyadmin/phpmyadmin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--js/functions.js12
-rw-r--r--js/server_databases.js4
-rw-r--r--libraries/DisplayResults.class.php6
-rw-r--r--libraries/structure.lib.php12
-rw-r--r--server_databases.php5
5 files changed, 21 insertions, 18 deletions
diff --git a/js/functions.js b/js/functions.js
index 875907282d..f07294a656 100644
--- a/js/functions.js
+++ b/js/functions.js
@@ -3755,14 +3755,13 @@ $(function () {
/**
* Watches checkboxes in a form to set the checkall box accordingly
*/
-var checkboxes_sel = "input.checkall:checkbox:enabled";
-$(checkboxes_sel).live("change", function () {
+var checkboxes_changed = function () {
var $form = $(this.form);
// total number of checkboxes in current form
var total_boxes = $form.find(checkboxes_sel).length;
// number of checkboxes checked in current form
var checked_boxes = $form.find(checkboxes_sel + ":checked").length;
- var $checkall = $form.find("input#checkall");
+ var $checkall = $form.find("input.checkall_box");
if (total_boxes == checked_boxes) {
$checkall.prop({checked: true, indeterminate: false});
}
@@ -3772,8 +3771,11 @@ $(checkboxes_sel).live("change", function () {
else {
$checkall.prop({checked: false, indeterminate: false});
}
-});
-$("input#checkall").live("change", function () {
+};
+var checkboxes_sel = "input.checkall:checkbox:enabled";
+$(checkboxes_sel).live("change", checkboxes_changed);
+
+$("input.checkall_box").live("change", function () {
var is_checked = $(this).is(":checked");
$(this.form).find(checkboxes_sel).prop("checked", is_checked)
.parents("tr").toggleClass("marked", is_checked);
diff --git a/libraries/DisplayResults.class.php b/libraries/DisplayResults.class.php
index a8a2b4c78e..d7e39d9888 100644
--- a/libraries/DisplayResults.class.php
+++ b/libraries/DisplayResults.class.php
@@ -5037,9 +5037,9 @@ class PMA_DisplayResults
. ' alt="' . __('With selected:') . '" />';
}
- $links_html .= '<input type="checkbox" id="checkall" title="'
- . __('Check All') . '" /> '
- . '<label for="checkall">' . __('Check All') . '</label> '
+ $links_html .= '<input type="checkbox" id="resultsForm_checkall" '
+ . 'class="checkall_box" title="' . __('Check All') . '" /> '
+ . '<label for="resultsForm_checkall">' . __('Check All') . '</label> '
. '<i style="margin-left: 2em">' . __('With selected:') . '</i>' . "\n";
$links_html .= PMA_Util::getButtonOrImage(
diff --git a/libraries/structure.lib.php b/libraries/structure.lib.php
index 3bdf0c1e6a..75b0e620fe 100644
--- a/libraries/structure.lib.php
+++ b/libraries/structure.lib.php
@@ -277,9 +277,9 @@ function PMA_getHtmlForCheckAllTables($pmaThemeImage, $text_dir,
. 'src="' .$pmaThemeImage .'arrow_'.$text_dir.'.png' . '"'
. 'width="38" height="22" alt="' . __('With selected:') . '" />';
- $html_output .= '<input type="checkbox" id="checkall" '
- . 'title="' . __('Check All') .'" />';
- $html_output .= '<label for="checkall">' .__('Check All') . '</label>';
+ $html_output .= '<input type="checkbox" id="tablesForm_checkall" '
+ . 'class="checkall_box" title="' . __('Check All') .'" />';
+ $html_output .= '<label for="tablesForm_checkall">' .__('Check All') . '</label>';
if ($overhead_check != '') {
$html_output .= PMA_getHtmlForCheckTablesHavingOverheadlink(
@@ -1356,9 +1356,9 @@ function PMA_getHtmlForCheckAllTableColumn($pmaThemeImage, $text_dir,
. 'src="' . $pmaThemeImage . 'arrow_' . $text_dir . '.png' . '"'
. 'width="38" height="22" alt="' . __('With selected:') . '" />';
- $html_output .= '<input type="checkbox" id="checkall" '
- . 'title="' . __('Check All') . '" />'
- . '<label for="checkall">' . __('Check All') . '</label>';
+ $html_output .= '<input type="checkbox" id="fieldsForm_checkall" '
+ . 'class="checkall_box" title="' . __('Check All') . '" />'
+ . '<label for="fieldsForm_checkall">' . __('Check All') . '</label>';
$html_output .= '<i style="margin-left: 2em">'
. __('With selected:') . '</i>';
diff --git a/server_databases.php b/server_databases.php
index d7c6fe13c2..2cb2b4e2fc 100644
--- a/server_databases.php
+++ b/server_databases.php
@@ -321,8 +321,9 @@ if ($databases_count > 0) {
$html .= '<img class="selectallarrow" src="'
. $pmaThemeImage . 'arrow_' . $text_dir . '.png"'
. ' width="38" height="22" alt="' . __('With selected:') . '" />' . "\n"
- . '<input type="checkbox" id="checkall" title="' . __('Check All') . '" /> '
- . '<label for="checkall">' . __('Check All') . '</label> '
+ . '<input type="checkbox" id="dbStatsForm_checkall" class="checkall_box" '
+ . 'title="' . __('Check All') . '" /> '
+ . '<label for="dbStatsForm_checkall">' . __('Check All') . '</label> '
. '<i style="margin-left: 2em">' . __('With selected:') . '</i>' . "\n";
$html .= PMA_Util::getButtonOrImage(
'',
diff --git a/js/server_databases.js b/js/server_databases.js
index 17dfb8e01b..c6e844fc8f 100644
--- a/js/server_databases.js
+++ b/js/server_databases.js
@@ -36,8 +36,8 @@ AJAX.registerOnload('server_databases.js', function () {
* @var selected_dbs Array containing the names of the checked databases
*/
var selected_dbs = [];
- // loop over all checked checkboxes, except the #checkall checkbox
- $form.find('input:checkbox:checked:not(#checkall)').each(function () {
+ // loop over all checked checkboxes, except the .checkall_box checkbox
+ $form.find('input:checkbox:checked:not(.checkall_box)').each(function () {
$(this).closest('tr').addClass('removeMe');
selected_dbs[selected_dbs.length] = 'DROP DATABASE `' + escapeHtml($(this).val()) + '`;';
});